@@ -15,161 +15,18 @@ $currentPage = 'cpanel-import';
 $MySQLMgmt = new mysqlmgmt();
 $pdo = $MySQLMgmt->getMySQLConnection();
 
-// Handle AJAX requests
-if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
-    header('Content-Type: application/json');
-    
-    try {
-        switch ($_POST['action']) {
-            case 'get_backup_files':
-                $result = ['success' => true, 'files' => getAvailableBackupFiles()];
-                echo json_encode($result);
-                break;
-                
-            case 'select_backup':
-                $result = selectBackupFile();
-                echo json_encode($result);
-                break;
-                
-            case 'start_import':
-                $result = startImport($_POST['backup_file']);
-                echo json_encode($result);
-                break;
-                
-            case 'get_import_status':
-                $result = getImportStatus($_POST['import_id']);
-                echo json_encode($result);
-                break;
-                
-            default:
-                echo json_encode(['success' => false, 'error' => 'Invalid action']);
-        }
-    } catch (Exception $e) {
-        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
-    }
-    exit;
-}
+// AJAX requests are handled by /api/cpanel-import-ajax.php
 
-function getAvailableBackupFiles() {
-    $userfilesDir = '/docker/users/' . AUTH_USER . '/userfiles';
-    $backupFiles = [];
-    
-    if (is_dir($userfilesDir)) {
-        $files = glob($userfilesDir . '/*.{tar.gz,tgz}', GLOB_BRACE);
-        foreach ($files as $file) {
-            $backupFiles[] = [
-                'filename' => basename($file),
-                'path' => $file,
-                'size' => filesize($file),
-                'modified' => filemtime($file)
-            ];
-        }
-        
-        // Sort by modification time (newest first)
-        usort($backupFiles, function($a, $b) {
-            return $b['modified'] - $a['modified'];
-        });
-    }
-    
-    return $backupFiles;
-}
 
-function selectBackupFile() {
-    if (!isset($_POST['backup_file'])) {
-        return ['success' => false, 'error' => 'No backup file selected'];
-    }
-    
-    $selectedFile = $_POST['backup_file'];
-    $userfilesDir = '/docker/users/' . AUTH_USER . '/userfiles';
-    $fullPath = $userfilesDir . '/' . basename($selectedFile);
-    
-    // Validate file exists and is in userfiles directory
-    if (!file_exists($fullPath) || dirname($fullPath) !== $userfilesDir) {
-        return ['success' => false, 'error' => 'Invalid backup file selected'];
-    }
-    
-    // Validate file extension
-    if (!preg_match('/\.(tar\.gz|tgz)$/i', $selectedFile)) {
-        return ['success' => false, 'error' => 'Invalid file type. Must be a .tar.gz or .tgz file'];
-    }
-    
-    return [
-        'success' => true,
-        'filename' => basename($selectedFile),
-        'path' => $fullPath,
-        'size' => filesize($fullPath)
-    ];
-}
 
-function startImport($backupFilePath) {
-    global $pdo;
-    
-    if (!file_exists($backupFilePath)) {
-        return ['success' => false, 'error' => 'Backup file not found'];
-    }
-    
-    // Create import record
-    $importId = uniqid('import_');
-    $stmt = $pdo->prepare("
-        INSERT INTO cpanel_imports (import_id, username, backup_file, status, created_at) 
-        VALUES (?, ?, ?, 'running', NOW())
-    ");
-    $stmt->execute([$importId, AUTH_USER, $backupFilePath]);
-    
-    // Start import in background
-    $command = "php " . __DIR__ . "/../scripts/run-cpanel-import.php " . 
-               escapeshellarg($importId) . " " . 
-               escapeshellarg(AUTH_USER) . " " . 
-               escapeshellarg($backupFilePath) . " > /dev/null 2>&1 &";
-    
-    exec($command);
-    
-    return [
-        'success' => true,
-        'import_id' => $importId
-    ];
-}
-
-function getImportStatus($importId) {
-    global $pdo;
-    
-    $stmt = $pdo->prepare("SELECT * FROM cpanel_imports WHERE import_id = ? AND username = ?");
-    $stmt->execute([$importId, AUTH_USER]);
-    $import = $stmt->fetch(PDO::FETCH_ASSOC);
-    
-    if (!$import) {
-        return ['success' => false, 'error' => 'Import not found'];
-    }
-    
-    return [
-        'success' => true,
-        'status' => $import['status'],
-        'progress' => $import['progress'] ?? 0,
-        'log' => $import['log'] ? json_decode($import['log'], true) : [],
-        'error' => $import['error_message'],
-        'completed_at' => $import['completed_at']
-    ];
-}
 ?>
 
-<!DOCTYPE html>
-<html lang="en">
-<head>
-    <meta charset="UTF-8">
-    <meta name="viewport" content="width=device-width, initial-scale=1.0">
-    <title><?php echo $pageTitle; ?> - WHP</title>
-    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
-    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
-</head>
-<body class="bg-light">
-    <div class="container mt-4">
+<!-- cPanel Backup Import Content -->
+<div class="container-fluid">
         <div class="row">
             <div class="col-12">
-                <div class="d-flex justify-content-between align-items-center mb-4">
+                <div class="mb-4">
                     <h2><i class="bi bi-upload"></i> cPanel Backup Import</h2>
-                    <a href="?page=dashboard" class="btn btn-outline-secondary">
-                        <i class="bi bi-arrow-left"></i> Back to Dashboard
-                    </a>
                 </div>
                 
                 <!-- Early Release Notice -->
@@ -340,7 +197,6 @@ function getImportStatus($importId) {
         </div>
     </div>
 
-    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
     <script>
         const nonce = '<?php echo $_SESSION['nonce'] ?? ''; ?>';
         let currentImportId = null;
@@ -355,7 +211,7 @@ function getImportStatus($importId) {
         // Refresh backup files list
         async function refreshBackupFiles() {
             try {
-                const response = await fetch('', {
+                const response = await fetch('/api/cpanel-import-ajax.php', {
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
@@ -432,7 +288,7 @@ function getImportStatus($importId) {
             }
 
             try {
-                const response = await fetch('', {
+                const response = await fetch('/api/cpanel-import-ajax.php', {
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
@@ -462,7 +318,7 @@ function getImportStatus($importId) {
 
         async function startImport(backupFilePath) {
             try {
-                const response = await fetch('', {
+                const response = await fetch('/api/cpanel-import-ajax.php', {
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
@@ -505,7 +361,7 @@ function getImportStatus($importId) {
             if (!currentImportId) return;
 
             try {
-                const response = await fetch('', {
+                const response = await fetch('/api/cpanel-import-ajax.php', {
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
@@ -629,5 +485,4 @@ function getImportStatus($importId) {
             return new Date(timestamp * 1000).toLocaleString();
         }
     </script>
-</body>
-</html>
\ No newline at end of file
+</div>
\ No newline at end of file
